pub struct AccessEntry {
pub principal_arn: String,
pub cluster_name: String,
pub arn: String,
pub kubernetes_groups: Vec<String>,
pub username: String,
pub type_: String,
pub created_at: DateTime<Utc>,
pub modified_at: DateTime<Utc>,
pub tags: TagMap,
pub associated_policies: Vec<AssociatedPolicy>,
}Expand description
An EKS access entry, a sub-resource of a cluster keyed by principal ARN. The access policies associated to the entry are a nested list.
Fields
principal_arn: Stringcluster_name: Stringarn: Stringkubernetes_groups: Vec<String>username: Stringtype_: Stringcreated_at: DateTime<Utc>modified_at: DateTime<Utc>associated_policies: Vec<AssociatedPolicy>Access policies associated to this entry, keyed by policy ARN order.