pub struct Addon {Show 13 fields
pub name: String,
pub arn: String,
pub cluster_name: String,
pub addon_version: String,
pub status: String,
pub created_at: DateTime<Utc>,
pub modified_at: DateTime<Utc>,
pub service_account_role_arn: Option<String>,
pub configuration_values: Option<String>,
pub namespace: Option<String>,
pub pod_identity_associations: Vec<String>,
pub tags: TagMap,
pub updates: BTreeMap<String, Update>,
}Expand description
An EKS add-on, a sub-resource of a cluster (e.g. vpc-cni, coredns).
Fields
name: Stringarn: Stringcluster_name: Stringaddon_version: Stringstatus: Stringcreated_at: DateTime<Utc>modified_at: DateTime<Utc>service_account_role_arn: Option<String>Present only when the caller supplied serviceAccountRoleArn.
configuration_values: Option<String>Present only when the caller supplied configurationValues.
namespace: Option<String>The custom install namespace, if the caller supplied namespaceConfig.
pod_identity_associations: Vec<String>Pod identity association ARNs (one per requested association), echoed
back as the podIdentityAssociations StringList on describe.
updates: BTreeMap<String, Update>Per-addon updates keyed by update id, disambiguated from cluster and
node-group updates by the addonName query param on Describe/ListUpdates.